@@ -1,9 +1,10 @@
-/* example-begin init.c */
 
+/*** block  from ../../docs/manual/basics-init.xml ***/
 #include <gst/gst.h>
 
 int
-main (int argc, char *argv[])
+main (int   argc,
+      char *argv[])
 {
   guint major, minor, micro;
 
@@ -15,4 +16,3 @@ main (int argc, char *argv[])
 
   return 0;
 }
-/* example-end init.c */
