@@ -154,8 +154,8 @@ gst_type_find_element_class_init (GstTypeFindElementClass * typefind_class)
   typefind_class->have_type = gst_type_find_element_have_type;
 
   g_object_class_install_property (gobject_class, ARG_CAPS,
-      g_param_spec_boxed ("caps", _("caps"),
-          _("detected capabilities in stream"), gst_caps_get_type (),
+      g_param_spec_boxed ("caps", _("stream type"),
+          _("detected type of stream"), gst_caps_get_type (),
           G_PARAM_READABLE));
   g_object_class_install_property (gobject_class, ARG_MINIMUM,
       g_param_spec_uint ("minimum", _("minimum"),
@@ -197,6 +197,7 @@ gst_type_find_element_init (GstTypeFindElement * typefind)
   gst_element_add_pad (GST_ELEMENT (typefind), typefind->src);
 
   typefind->caps = NULL;
+  typefind->pending_events = NULL;
   typefind->min_probability = 1;
   typefind->max_probability = GST_TYPE_FIND_MAXIMUM;
 
@@ -412,7 +413,18 @@ push_buffer_store (GstTypeFindElement * typefind)
 {
   guint size = gst_buffer_store_get_size (typefind->store, 0);
   GstBuffer *buffer;
+  const GList *item;
 
+  /* handle pending events */
+  for (item = typefind->pending_events; item; item = item->next) {
+    GstEvent *e = item->data;
+
+    gst_pad_push (typefind->src, GST_DATA (e));
+  }
+  g_list_free (typefind->pending_events);
+  typefind->pending_events = NULL;
+
+  /* data */
   gst_pad_push (typefind->src, GST_DATA (gst_event_new_discontinuous (TRUE,
               GST_FORMAT_DEFAULT, (guint64) 0, GST_FORMAT_BYTES, (guint64) 0,
               GST_FORMAT_UNDEFINED)));
@@ -443,7 +455,7 @@ find_element_get_length (gpointer data)
   if (entry->self->stream_length == 0) {
     typefind->stream_length_available =
         gst_pad_query (GST_PAD_PEER (entry->self->sink), GST_QUERY_TOTAL,
-        &format, &entry->self->stream_length);
+        &format, (gint64 *) & entry->self->stream_length);
     if (format != GST_FORMAT_BYTES)
       typefind->stream_length_available = FALSE;
     if (!typefind->stream_length_available) {
@@ -484,6 +496,7 @@ gst_type_find_element_handle_event (GstPad * pad, GstEvent * event)
             g_signal_emit (typefind, gst_type_find_element_signals[HAVE_TYPE],
                 0, entry->probability, entry->caps);
             stop_typefinding (typefind);
+            push_buffer_store (typefind);
             gst_pad_event_default (pad, event);
           } else {
             gst_pad_event_default (pad, event);
@@ -492,8 +505,13 @@ gst_type_find_element_handle_event (GstPad * pad, GstEvent * event)
             stop_typefinding (typefind);
           }
           break;
+        case GST_EVENT_DISCONTINUOUS:
+        case GST_EVENT_FLUSH:
+          gst_event_unref (event);
+          break;
         default:
-          gst_data_unref (GST_DATA (event));
+          typefind->pending_events = g_list_append (typefind->pending_events,
+              event);
           break;
       }
       break;
@@ -503,15 +521,14 @@ gst_type_find_element_handle_event (GstPad * pad, GstEvent * event)
           start_typefinding (typefind);
           gst_event_unref (event);
         } else {
-          guint64 off;
+          gint64 off;
 
           if (gst_event_discont_get_value (event, GST_FORMAT_BYTES, &off) &&
               off == typefind->waiting_for_discont_offset) {
             typefind->mode = MODE_NORMAL;
             push_buffer_store (typefind);
-          } else {
-            gst_event_unref (event);
           }
+          gst_event_unref (event);
         }
       } else if (GST_EVENT_TYPE (event) == GST_EVENT_EOS) {
         push_buffer_store (typefind);
@@ -816,6 +833,9 @@ gst_type_find_element_change_state (GstElement * element)
     case GST_STATE_PAUSED_TO_READY:
       stop_typefinding (typefind);
       gst_caps_replace (&typefind->caps, NULL);
+      g_list_foreach (typefind->pending_events, (GFunc) gst_data_unref, NULL);
+      g_list_free (typefind->pending_events);
+      typefind->pending_events = NULL;
       break;
     default:
       break;
