@@ -71,6 +71,8 @@ extern GstDebugCategory *GST_CAT_ERROR_SYSTEM;
 extern GstDebugCategory *GST_CAT_EVENT;
 extern GstDebugCategory *GST_CAT_PARAMS;
 extern GstDebugCategory *GST_CAT_CALL_TRACE;
+extern GstDebugCategory *GST_CAT_SIGNAL;
+extern GstDebugCategory *GST_CAT_PROBE;
 
 #else
 
@@ -101,6 +103,8 @@ extern GstDebugCategory *GST_CAT_CALL_TRACE;
 #define GST_CAT_EVENT            NULL
 #define GST_CAT_PARAMS           NULL
 #define GST_CAT_CALL_TRACE       NULL
+#define GST_CAT_SIGNAL           NULL
+#define GST_CAT_PROBE            NULL
 
 #endif
 
