@@ -20,9 +20,11 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include "gstatomic_impl.h"
+
 #define _GST_DATA_INIT(data, ptype, pflags, pfree, pcopy) 	\
 G_STMT_START {							\
-  GST_ATOMIC_INT_INIT (&(data)->refcount, 1);			\
+  gst_atomic_int_init (&(data)->refcount, 1);			\
   (data)->type = ptype;						\
   (data)->flags = pflags;					\
   (data)->free = pfree;						\
@@ -31,6 +33,6 @@ G_STMT_START {							\
 
 #define _GST_DATA_DISPOSE(data)				 	\
 G_STMT_START {							\
-  GST_ATOMIC_INT_FREE (&(data)->refcount);			\
+  gst_atomic_int_destroy (&(data)->refcount);			\
 } G_STMT_END;
 
