@@ -70,7 +70,7 @@ struct _GstElementDetails {
 #define GST_STATE_PAUSED_TO_READY	((GST_STATE_PAUSED<<8) | GST_STATE_READY)
 #define GST_STATE_READY_TO_NULL		((GST_STATE_READY<<8) | GST_STATE_NULL)
 
-extern GType _gst_element_type;
+GST_EXPORT GType _gst_element_type;
 
 #define GST_TYPE_ELEMENT		(_gst_element_type)
 #define GST_IS_ELEMENT(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), GST_TYPE_ELEMENT))
@@ -126,6 +126,9 @@ typedef enum {
   /* element is in error */
   GST_ELEMENT_IN_ERROR,
 
+  /* element doesn't change passed buffer or change it in place */
+  GST_ELEMENT_WORK_IN_PLACE,
+  
   /* use some padding for future expansion */
   GST_ELEMENT_FLAG_LAST		= GST_OBJECT_FLAG_LAST + 16
 } GstElementFlags;
@@ -136,15 +139,28 @@ typedef enum {
 
 #define GST_ELEMENT_NAME(obj)			(GST_OBJECT_NAME(obj))
 #define GST_ELEMENT_PARENT(obj)			(GST_OBJECT_PARENT(obj))
-#define GST_ELEMENT_MANAGER(obj)		(((GstElement*)(obj))->manager)
 #define GST_ELEMENT_SCHED(obj)			(((GstElement*)(obj))->sched)
 #define GST_ELEMENT_CLOCK(obj)			(((GstElement*)(obj))->clock)
 #define GST_ELEMENT_PADS(obj)			((obj)->pads)
 
+/**
+ * GST_ELEMENT_ERROR:
+ * @el: the element that throws the error
+ * @domain: like CORE, LIBRARY, RESOURCE or STREAM (see #GstError)
+ * @code: error code defined for that domain (see #GstError)
+ * @message: the message to display (format string and args enclosed in round brackets)
+ * @debug: debugging information for the message (format string and args enclosed in round brackets)
+ *
+ * Utility function that elements can use in case they encountered a fatal
+ * data processing error. The pipeline will throw an error signal and the
+ * application will be requested to stop further media processing.
+ */
 #define GST_ELEMENT_ERROR(el, domain, code, message, debug) G_STMT_START { \
   gchar *__msg = _gst_element_error_printf message; \
   gchar *__dbg = _gst_element_error_printf debug; \
-  GST_ERROR_OBJECT (el, "%s", __msg); \
+  if (__msg) \
+    GST_ERROR_OBJECT (el, "%s", __msg); \
+  if (__dbg) \
   GST_ERROR_OBJECT (el, "%s", __dbg); \
   gst_element_error_full (GST_ELEMENT(el), \
   GST_ ## domain ## _ERROR, GST_ ## domain ## _ERROR_ ## code, \
@@ -245,7 +261,11 @@ struct _GstElementClass {
   void			(*set_index)		(GstElement *element, GstIndex *index);
 
   GstElementStateReturn	(*set_state)		(GstElement *element, GstElementState state);
-  gpointer _gst_reserved[GST_PADDING];
+
+  /* FIXME 0.9: move up to signals */
+  void			(*no_more_pads)		(GstElement *element);
+  
+  gpointer _gst_reserved[GST_PADDING - 1];
 };
 
 void			gst_element_class_add_pad_template	(GstElementClass *klass, GstPadTemplate *templ);
@@ -313,7 +333,10 @@ GstScheduler*		gst_element_get_scheduler	(GstElement *element);
 void			gst_element_add_pad		(GstElement *element, GstPad *pad);
 void			gst_element_remove_pad		(GstElement *element, GstPad *pad);
 GstPad *		gst_element_add_ghost_pad	(GstElement *element, GstPad *pad, const gchar *name);
+#ifndef GST_DISABLE_DEPRECATED
 void			gst_element_remove_ghost_pad	(GstElement *element, GstPad *pad);
+#endif
+void			gst_element_no_more_pads	(GstElement *element);
 
 GstPad*			gst_element_get_pad		(GstElement *element, const gchar *name);
 GstPad*			gst_element_get_static_pad	(GstElement *element, const gchar *name);
