@@ -41,6 +41,24 @@ static GstStaticPadTemplate srctemplate = GST_STATIC_PAD_TEMPLATE ("src",
     GST_STATIC_CAPS_ANY);
 
 GST_DEBUG_CATEGORY_STATIC (queue_dataflow);
+#define GST_CAT_DEFAULT (queue_dataflow)
+
+#define STATUS(queue, msg) \
+  GST_CAT_LOG_OBJECT (queue_dataflow, queue, \
+		      "(%s:%s) " msg ": %u of %u-%u buffers, %u of %u-%u " \
+		      "bytes, %" G_GUINT64_FORMAT " of %" G_GUINT64_FORMAT \
+		      "-%" G_GUINT64_FORMAT " ns, %u elements", \
+		      GST_DEBUG_PAD_NAME (pad), \
+		      queue->cur_level.buffers, \
+		      queue->min_threshold.buffers, \
+		      queue->max_size.buffers, \
+		      queue->cur_level.bytes, \
+		      queue->min_threshold.bytes, \
+		      queue->max_size.bytes, \
+		      queue->cur_level.time, \
+		      queue->min_threshold.time, \
+		      queue->max_size.time, \
+		      queue->queue->length)
 
 static GstElementDetails gst_queue_details = GST_ELEMENT_DETAILS ("Queue",
     "Generic",
@@ -120,7 +138,9 @@ static gboolean gst_queue_handle_src_query (GstPad * pad,
     GstQueryType type, GstFormat * fmt, gint64 * value);
 
 static GstCaps *gst_queue_getcaps (GstPad * pad);
-static GstPadLinkReturn gst_queue_link (GstPad * pad, const GstCaps * caps);
+static GstPadLinkReturn
+gst_queue_link_sink (GstPad * pad, const GstCaps * caps);
+static GstPadLinkReturn gst_queue_link_src (GstPad * pad, const GstCaps * caps);
 static void gst_queue_locked_flush (GstQueue * queue);
 
 static GstElementStateReturn gst_queue_change_state (GstElement * element);
@@ -288,7 +308,7 @@ gst_queue_init (GstQueue * queue)
       GST_DEBUG_FUNCPTR (gst_queue_chain));
   gst_element_add_pad (GST_ELEMENT (queue), queue->sinkpad);
   gst_pad_set_link_function (queue->sinkpad,
-      GST_DEBUG_FUNCPTR (gst_queue_link));
+      GST_DEBUG_FUNCPTR (gst_queue_link_sink));
   gst_pad_set_getcaps_function (queue->sinkpad,
       GST_DEBUG_FUNCPTR (gst_queue_getcaps));
   gst_pad_set_active (queue->sinkpad, TRUE);
@@ -298,7 +318,8 @@ gst_queue_init (GstQueue * queue)
       "src");
   gst_pad_set_get_function (queue->srcpad, GST_DEBUG_FUNCPTR (gst_queue_get));
   gst_element_add_pad (GST_ELEMENT (queue), queue->srcpad);
-  gst_pad_set_link_function (queue->srcpad, GST_DEBUG_FUNCPTR (gst_queue_link));
+  gst_pad_set_link_function (queue->srcpad,
+      GST_DEBUG_FUNCPTR (gst_queue_link_src));
   gst_pad_set_getcaps_function (queue->srcpad,
       GST_DEBUG_FUNCPTR (gst_queue_getcaps));
   gst_pad_set_event_function (queue->srcpad,
@@ -333,6 +354,8 @@ gst_queue_init (GstQueue * queue)
 
   GST_CAT_DEBUG_OBJECT (GST_CAT_THREAD, queue,
       "initialized queue's not_empty & not_full conditions");
+
+  GST_FLAG_SET (queue, GST_ELEMENT_WORK_IN_PLACE);
 }
 
 /* called only once, as opposed to dispose */
@@ -358,6 +381,7 @@ gst_queue_finalize (GObject * object)
     GstQueueEventResponse *er = g_queue_pop_head (queue->events);
 
     gst_event_unref (er->event);
+    g_free (er);
   }
   g_mutex_unlock (queue->event_lock);
   g_mutex_free (queue->event_lock);
@@ -374,7 +398,7 @@ gst_queue_getcaps (GstPad * pad)
 
   queue = GST_QUEUE (gst_pad_get_parent (pad));
 
-  if (queue->cur_level.bytes > 0) {
+  if (pad == queue->srcpad && queue->cur_level.bytes > 0) {
     return gst_caps_copy (queue->negotiated_caps);
   }
 
@@ -382,7 +406,50 @@ gst_queue_getcaps (GstPad * pad)
 }
 
 static GstPadLinkReturn
-gst_queue_link (GstPad * pad, const GstCaps * caps)
+gst_queue_link_sink (GstPad * pad, const GstCaps * caps)
+{
+  GstQueue *queue;
+  GstPadLinkReturn link_ret;
+
+  queue = GST_QUEUE (gst_pad_get_parent (pad));
+
+  if (queue->cur_level.bytes > 0) {
+    if (gst_caps_is_equal (caps, queue->negotiated_caps)) {
+      return GST_PAD_LINK_OK;
+    } else if (GST_STATE (queue) != GST_STATE_PLAYING) {
+      return GST_PAD_LINK_DELAYED;
+    }
+
+    /* Wait until the queue is empty before attempting the pad
+       negotiation. */
+    GST_QUEUE_MUTEX_LOCK;
+
+    STATUS (queue, "waiting for queue to get empty");
+    while (queue->cur_level.bytes > 0) {
+      g_cond_wait (queue->item_del, queue->qlock);
+      if (queue->interrupt) {
+        GST_QUEUE_MUTEX_UNLOCK;
+        return GST_PAD_LINK_DELAYED;
+      }
+    }
+    STATUS (queue, "queue is now empty");
+
+    GST_QUEUE_MUTEX_UNLOCK;
+  }
+
+  link_ret = gst_pad_proxy_pad_link (pad, caps);
+
+  if (GST_PAD_LINK_SUCCESSFUL (link_ret)) {
+    /* we store an extra copy of the negotiated caps, just in case
+     * the pads become unnegotiated while we have buffers */
+    gst_caps_replace (&queue->negotiated_caps, gst_caps_copy (caps));
+  }
+
+  return link_ret;
+}
+
+static GstPadLinkReturn
+gst_queue_link_src (GstPad * pad, const GstCaps * caps)
 {
   GstQueue *queue;
   GstPadLinkReturn link_ret;
@@ -410,6 +477,8 @@ gst_queue_link (GstPad * pad, const GstCaps * caps)
 static void
 gst_queue_locked_flush (GstQueue * queue)
 {
+  GST_CAT_LOG_OBJECT (queue_dataflow, queue, "Flushing contents...");
+
   while (!g_queue_is_empty (queue->queue)) {
     GstData *data = g_queue_pop_head (queue->queue);
 
@@ -442,6 +511,7 @@ gst_queue_handle_pending_events (GstQueue * queue)
   g_mutex_lock (queue->event_lock);
   while (!g_queue_is_empty (queue->events)) {
     GstQueueEventResponse *er;
+    gboolean need_response;
 
     er = g_queue_pop_head (queue->events);
 
@@ -456,32 +526,23 @@ gst_queue_handle_pending_events (GstQueue * queue)
       break;
     }
     g_mutex_unlock (queue->event_lock);
+
+    need_response =
+        GST_DATA_FLAG_IS_SET (GST_DATA (er->event),
+        GST_EVENT_COMMON_FLAG_NEED_RESPONSE);
     er->ret = gst_pad_event_default (queue->srcpad, er->event);
-    er->handled = TRUE;
-    g_cond_signal (queue->event_done);
+    if (need_response) {
+      er->handled = TRUE;
+      g_cond_signal (queue->event_done);
+    } else {
+      g_free (er);
+    }
     g_mutex_lock (queue->event_lock);
     GST_CAT_DEBUG_OBJECT (queue_dataflow, queue, "event sent");
   }
   g_mutex_unlock (queue->event_lock);
 }
 
-#define STATUS(queue, msg) \
-  GST_CAT_LOG_OBJECT (queue_dataflow, queue, \
-		      "(%s:%s) " msg ": %u of %u-%u buffers, %u of %u-%u " \
-		      "bytes, %" G_GUINT64_FORMAT " of %" G_GUINT64_FORMAT \
-		      "-%" G_GUINT64_FORMAT " ns, %u elements", \
-		      GST_DEBUG_PAD_NAME (pad), \
-		      queue->cur_level.buffers, \
-		      queue->min_threshold.buffers, \
-		      queue->max_size.buffers, \
-		      queue->cur_level.bytes, \
-		      queue->min_threshold.bytes, \
-		      queue->max_size.bytes, \
-		      queue->cur_level.time, \
-		      queue->min_threshold.time, \
-		      queue->max_size.time, \
-		      queue->queue->length)
-
 static void
 gst_queue_chain (GstPad * pad, GstData * data)
 {
@@ -522,7 +583,9 @@ restart:
 
   if (GST_IS_BUFFER (data))
     GST_CAT_LOG_OBJECT (queue_dataflow, queue,
-        "adding buffer %p of size %d", data, GST_BUFFER_SIZE (data));
+        "adding buffer %p of size %d and time %" GST_TIME_FORMAT,
+        data, GST_BUFFER_SIZE (data),
+        GST_TIME_ARGS (GST_BUFFER_TIMESTAMP (data)));
 
   /* We make space available if we're "full" according to whatever
    * the user defined as "full". Note that this only applies to buffers.
@@ -607,12 +670,14 @@ restart:
            * or its manager, switch back to iterator so bottom
            * half of state change executes */
           if (queue->interrupt) {
+            GstScheduler *sched;
+
             GST_CAT_DEBUG_OBJECT (queue_dataflow, queue, "interrupted");
-            GST_QUEUE_MUTEX_UNLOCK;
-            if (gst_scheduler_interrupt (gst_pad_get_scheduler (queue->sinkpad),
-                    GST_ELEMENT (queue))) {
-              goto out_unref;
+            sched = gst_pad_get_scheduler (queue->sinkpad);
+            if (!sched || gst_scheduler_interrupt (sched, GST_ELEMENT (queue))) {
+              goto ignore_interrupt;
             }
+            GST_QUEUE_MUTEX_UNLOCK;
             /* if we got here because we were unlocked after a
              * flush, we don't need to add the buffer to the
              * queue again */
@@ -644,6 +709,7 @@ restart:
             }
           }
 
+        ignore_interrupt:
           /* OK, we've got a serious issue here. Imagine the situation
            * where the puller (next element) is sending an event here,
            * so it cannot pull events from the queue, and we cannot
@@ -652,9 +718,16 @@ restart:
            * that, we handle pending upstream events here, too. */
           gst_queue_handle_pending_events (queue);
 
-          STATUS (queue, "waiting for item_del signal from thread using qlock");
-          g_cond_wait (queue->item_del, queue->qlock);
-          STATUS (queue, "received item_del signal from thread using qlock");
+          if (!queue->interrupt) {
+            STATUS (queue,
+                "waiting for item_del signal from thread using qlock");
+            g_cond_wait (queue->item_del, queue->qlock);
+            STATUS (queue, "received item_del signal from thread using qlock");
+          } else {
+            GST_CAT_DEBUG_OBJECT (queue_dataflow, queue,
+                "Not waiting, just adding buffer, after interrupt (bad!)");
+            break;
+          }
         }
 
         STATUS (queue, "post-full wait");
@@ -731,10 +804,12 @@ restart:
        * manager, switch back to iterator so bottom half of state
        * change executes. */
       if (queue->interrupt) {
+        GstScheduler *sched;
+
         GST_CAT_DEBUG_OBJECT (queue_dataflow, queue, "interrupted");
         GST_QUEUE_MUTEX_UNLOCK;
-        if (gst_scheduler_interrupt (gst_pad_get_scheduler (queue->srcpad),
-                GST_ELEMENT (queue)))
+        sched = gst_pad_get_scheduler (queue->srcpad);
+        if (!sched || gst_scheduler_interrupt (sched, GST_ELEMENT (queue)))
           return GST_DATA (gst_event_new (GST_EVENT_INTERRUPT));
         goto restart;
       }
@@ -797,6 +872,9 @@ restart:
     queue->cur_level.bytes -= GST_BUFFER_SIZE (data);
     if (GST_BUFFER_DURATION (data) != GST_CLOCK_TIME_NONE)
       queue->cur_level.time -= GST_BUFFER_DURATION (data);
+    GST_CAT_LOG_OBJECT (queue_dataflow, queue,
+        "Got buffer of time %" GST_TIME_FORMAT,
+        GST_TIME_ARGS (GST_BUFFER_TIMESTAMP (data)));
   }
 
   /* Now that we're done, we can lose our own reference to
@@ -835,28 +913,41 @@ gst_queue_handle_src_event (GstPad * pad, GstEvent * event)
 {
   GstQueue *queue = GST_QUEUE (gst_pad_get_parent (pad));
   gboolean res;
+  GstQueueEventResponse *er = NULL;
 
   GST_CAT_DEBUG_OBJECT (queue_dataflow, queue, "got event %p (%d)",
       event, GST_EVENT_TYPE (event));
   GST_QUEUE_MUTEX_LOCK;
 
   if (gst_element_get_state (GST_ELEMENT (queue)) == GST_STATE_PLAYING) {
-    GstQueueEventResponse er;
+    gboolean need_response = GST_DATA_FLAG_IS_SET (GST_DATA (event),
+        GST_EVENT_COMMON_FLAG_NEED_RESPONSE);
+
+    er = g_new (GstQueueEventResponse, 1);
 
     /* push the event to the queue and wait for upstream consumption */
-    er.event = event;
-    er.handled = FALSE;
+    er->event = event;
+    er->handled = FALSE;
+
     g_mutex_lock (queue->event_lock);
     GST_CAT_DEBUG_OBJECT (queue_dataflow, queue,
         "putting event %p (%d) on internal queue", event,
         GST_EVENT_TYPE (event));
-    g_queue_push_tail (queue->events, &er);
+    g_queue_push_tail (queue->events, er);
     g_mutex_unlock (queue->event_lock);
+
+    if (!need_response) {
+      /* Leave for upstream to delete */
+      er = NULL;
+      res = TRUE;
+      goto handled;
+    }
+
     GST_CAT_WARNING_OBJECT (queue_dataflow, queue,
         "Preparing for loop for event handler");
     /* see the chain function on why this is here - it prevents a deadlock */
     g_cond_signal (queue->item_del);
-    while (!er.handled) {
+    while (!er->handled) {
       GTimeVal timeout;
 
       g_get_current_time (&timeout);
@@ -864,10 +955,10 @@ gst_queue_handle_src_event (GstPad * pad, GstEvent * event)
       GST_LOG_OBJECT (queue, "doing g_cond_wait using qlock from thread %p",
           g_thread_self ());
       if (!g_cond_timed_wait (queue->event_done, queue->qlock, &timeout) &&
-          !er.handled) {
+          !er->handled) {
         GST_CAT_WARNING_OBJECT (queue_dataflow, queue,
             "timeout in upstream event handling, dropping event %p (%d)",
-            er.event, GST_EVENT_TYPE (er.event));
+            er->event, GST_EVENT_TYPE (er->event));
         g_mutex_lock (queue->event_lock);
         /* since this queue is for src events (ie upstream), this thread is
          * the only one that is pushing stuff on it, so we're sure that
@@ -876,13 +967,13 @@ gst_queue_handle_src_event (GstPad * pad, GstEvent * event)
          * the list. */
         g_queue_pop_tail (queue->events);
         g_mutex_unlock (queue->event_lock);
-        gst_event_unref (er.event);
+        gst_event_unref (er->event);
         res = FALSE;
         goto handled;
       }
     }
     GST_CAT_WARNING_OBJECT (queue_dataflow, queue, "Event handled");
-    res = er.ret;
+    res = er->ret;
   } else {
     res = gst_pad_event_default (pad, event);
 
@@ -896,6 +987,7 @@ gst_queue_handle_src_event (GstPad * pad, GstEvent * event)
         if (GST_EVENT_SEEK_FLAGS (event) & GST_SEEK_FLAG_FLUSH) {
           gst_queue_locked_flush (queue);
         }
+        break;
       default:
         break;
     }
@@ -903,6 +995,9 @@ gst_queue_handle_src_event (GstPad * pad, GstEvent * event)
 handled:
   GST_QUEUE_MUTEX_UNLOCK;
 
+  if (er)
+    g_free (er);
+
   return res;
 }
 
@@ -923,10 +1018,16 @@ gst_queue_handle_src_query (GstPad * pad,
     /* FIXME: this code assumes that there's no discont in the queue */
     switch (*fmt) {
       case GST_FORMAT_BYTES:
-        *value -= queue->cur_level.bytes;
+        if (*value >= queue->cur_level.bytes)
+          *value -= queue->cur_level.bytes;
+        else
+          *value = 0;
         break;
       case GST_FORMAT_TIME:
-        *value -= queue->cur_level.time;
+        if (*value >= queue->cur_level.time)
+          *value -= queue->cur_level.time;
+        else
+          *value = 0;
         break;
       default:
         /* FIXME */
@@ -961,7 +1062,8 @@ gst_queue_change_state (GstElement * element)
 
   queue = GST_QUEUE (element);
 
-  GST_CAT_LOG_OBJECT (GST_CAT_STATES, element, "starting state change");
+  GST_CAT_LOG_OBJECT (GST_CAT_STATES, element,
+      "starting state change 0x%x", GST_STATE_TRANSITION (element));
 
   /* lock the queue so another thread (not in sync with this thread's state)
    * can't call this queue's _get (or whatever)
@@ -1009,6 +1111,8 @@ gst_queue_change_state (GstElement * element)
       break;
   }
 
+  GST_QUEUE_MUTEX_UNLOCK;
+
   if (GST_ELEMENT_CLASS (parent_class)->change_state)
     ret = GST_ELEMENT_CLASS (parent_class)->change_state (element);
 
@@ -1018,6 +1122,10 @@ gst_queue_change_state (GstElement * element)
   gst_pad_set_active (queue->sinkpad, TRUE);
   gst_pad_set_active (queue->srcpad, TRUE);
 
+  GST_CAT_LOG_OBJECT (GST_CAT_STATES, element, "done with state change");
+
+  return ret;
+
 unlock:
   GST_QUEUE_MUTEX_UNLOCK;
 
