@@ -31,6 +31,7 @@
 #include "dparammanager.h"
 
 GST_DEBUG_CATEGORY_EXTERN (_gst_control_debug);
+#define GST_CAT_DEFAULT _gst_control_debug
 
 static void gst_dpsmooth_class_init (GstDParamSmoothClass * klass);
 static void gst_dpsmooth_init (GstDParamSmooth * dparam);
@@ -73,6 +74,7 @@ gst_dpsmooth_get_type (void)
       0,
       (GInstanceInitFunc) gst_dpsmooth_init,
     };
+
     dpsmooth_type =
         g_type_register_static (GST_TYPE_DPARAM, "GstDParamSmooth",
         &dpsmooth_info, 0);
@@ -132,6 +134,8 @@ gst_dpsmooth_init (GstDParamSmooth * dpsmooth)
  * gst_dpsmooth_new:
  * @type: the type that this dparam will store
  *
+ * Create a new dynamic parameter controller which smoothes control changes.
+ *
  * Returns: a new instance of GstDParam
  */
 GstDParam *
