@@ -205,7 +205,6 @@ print_factory_details_info (GstElementFactory * factory)
       get_rank_name (GST_PLUGIN_FEATURE (factory)->rank),
       GST_PLUGIN_FEATURE (factory)->rank);
   n_print ("\n");
-
 }
 
 static void
@@ -236,11 +235,31 @@ print_hierarchy (GType type, gint level, gint * maxlevel)
     n_print ("\n");
 }
 
+static void
+print_interfaces (GType type)
+{
+  guint n_ifaces;
+  GType *iface, *ifaces = g_type_interfaces (type, &n_ifaces);
+
+  if (ifaces) {
+    if (n_ifaces) {
+      g_print ("Implemented Interfaces:\n");
+      iface = ifaces;
+      while (*iface) {
+        g_print ("  %s\n", g_type_name (*iface));
+        iface++;
+      }
+      g_print ("\n");
+      g_free (ifaces);
+    }
+  }
+}
+
 static void
 print_element_properties_info (GstElement * element)
 {
   GParamSpec **property_specs;
-  gint num_properties, i;
+  guint num_properties, i;
   gboolean readable;
   const char *string_val;
 
@@ -644,12 +663,12 @@ print_pad_info (GstElement * element)
 
     n_print ("");
 
-    if (gst_pad_get_direction (pad) == GST_PAD_SRC)
+    if (gst_pad_get_direction (GST_PAD (realpad)) == GST_PAD_SRC)
       g_print ("  SRC: '%s'", gst_pad_get_name (pad));
-    else if (gst_pad_get_direction (pad) == GST_PAD_SINK)
+    else if (gst_pad_get_direction (GST_PAD (realpad)) == GST_PAD_SINK)
       g_print ("  SINK: '%s'", gst_pad_get_name (pad));
     else
-      g_print ("  UNKNOWN!!!: '%s'\n", gst_pad_get_name (pad));
+      g_print ("  UNKNOWN!!!: '%s'", gst_pad_get_name (pad));
 
     if (GST_IS_GHOST_PAD (pad))
       g_print (", ghost of real pad %s:%s\n", GST_DEBUG_PAD_NAME (realpad));
@@ -822,9 +841,15 @@ print_signal_info (GstElement * element)
           query->signal_name,
           g_type_name (query->return_type), g_type_name (type));
 
-      for (j = 0; j < query->n_params; j++)
-        g_print (",\n%s%s%s arg%d", _name, indent,
-            g_type_name (query->param_types[j]), j);
+      for (j = 0; j < query->n_params; j++) {
+        if (G_TYPE_IS_FUNDAMENTAL (query->param_types[j])) {
+          g_print (",\n%s%s%s arg%d", _name, indent,
+              g_type_name (query->param_types[j]), j);
+        } else {
+          g_print (",\n%s%s%s* arg%d", _name, indent,
+              g_type_name (query->param_types[j]), j);
+        }
+      }
 
       if (k == 0)
         g_print (",\n%s%sgpointer user_data);\n", _name, indent);
@@ -942,6 +967,20 @@ print_element_list (gboolean print_all)
 
 static void
 print_plugin_info (GstPlugin * plugin)
+{
+  n_print ("Plugin Details:\n");
+  n_print ("  Name:\t\t%s\n", plugin->desc.name);
+  n_print ("  Description:\t%s\n", plugin->desc.description);
+  n_print ("  Filename:\t%s\n", plugin->filename ? plugin->filename : "(null)");
+  n_print ("  Version:\t%s\n", plugin->desc.version);
+  n_print ("  License:\t%s\n", plugin->desc.license);
+  n_print ("  Package:\t%s\n", plugin->desc.package);
+  n_print ("  Origin URL:\t%s\n", plugin->desc.origin);
+  n_print ("\n");
+}
+
+static void
+print_plugin_features (GstPlugin * plugin)
 {
   GList *features;
   gint num_features = 0;
@@ -951,16 +990,6 @@ print_plugin_info (GstPlugin * plugin)
   gint num_indexes = 0;
   gint num_other = 0;
 
-  n_print ("Plugin Details:\n");
-  n_print ("  Name:\t\t%s\n", plugin->desc.name);
-  n_print ("  Description:\t%s\n", plugin->desc.description);
-  n_print ("  Filename:\t%s\n", plugin->filename);
-  n_print ("  Version:\t%s\n", plugin->desc.version);
-  n_print ("  License:\t%s\n", plugin->desc.license);
-  n_print ("  Package:\t%s\n", plugin->desc.package);
-  n_print ("  Origin URL:\t%s\n", plugin->desc.origin);
-  n_print ("\n");
-
   features = gst_plugin_get_feature_list (plugin);
 
   while (features) {
@@ -997,6 +1026,7 @@ print_plugin_info (GstPlugin * plugin)
           g_print ("%s%s", i > 0 ? ", " : "", factory->extensions[i]);
           i++;
         }
+        g_print ("\n");
       } else
         g_print ("%s type: N/A\n", plugin->desc.name);
 
@@ -1086,8 +1116,14 @@ print_element_info (GstElementFactory * factory, gboolean print_names)
     _name = "";
 
   print_factory_details_info (factory);
+  if (GST_PLUGIN_FEATURE (factory)->manager) {
+    GstPlugin *plugin = (GstPlugin *) GST_PLUGIN_FEATURE (factory)->manager;
+
+    print_plugin_info (plugin);
+  }
 
   print_hierarchy (G_OBJECT_TYPE (element), 0, &maxlevel);
+  print_interfaces (G_OBJECT_TYPE (element));
 
   print_pad_templates_info (element, factory);
   print_element_flag_info (element);
@@ -1155,6 +1191,7 @@ main (int argc, char *argv[])
       /* if there is such a plugin, print out info */
       if (plugin) {
         print_plugin_info (plugin);
+        print_plugin_features (plugin);
       } else {
         g_print ("No such element or plugin '%s'\n", arg);
         return -1;
